.. _release:

**********
What's new
**********

This is the list of changes to cartopy between each release. For full details,
see the `commit logs <https://github.com/scitools/cartopy/commits/>`_. For install and
upgrade instructions, see :ref:`installing`.

Versions
--------

.. toctree::
   :maxdepth: 2

   v0.21
   v0.20
   v0.19
   v0.18
   v0.17
   v0.16
   v0.15
   v0.14
   v0.13
   v0.12
   v0.11
   v0.10
   v0.9
   v0.8
   v0.7
   v0.6
   v0.5
